@@ -1,6 +1,6 @@
 ;;; magit-branch.el --- Branch support  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2008-2025 The Magit Project Contributors
+;; Copyright (C) 2008-2026 The Magit Project Contributors
 
 ;; Author: Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
 ;; Maintainer: Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
@@ -314,10 +314,10 @@ branch.  This is similar to what `magit-branch-and-checkout'
 does."
   (declare (interactive-only magit-call-git))
   (interactive
-   (let ((arg (magit-read-other-branch-or-commit "Checkout")))
-     (list arg
-           (and (not (magit-commit-p arg))
-                (magit-read-starting-point "Create and checkout branch" arg)))))
+    (let ((arg (magit-read-other-branch-or-commit "Checkout")))
+      (list arg
+            (and (not (magit-commit-p arg))
+                 (magit-read-starting-point "Create and checkout branch" arg)))))
   (when (string-match "\\`heads/\\(.+\\)" arg)
     (setq arg (match-str 1 arg)))
   (if start-point
@@ -352,50 +352,50 @@ value of `magit-branch-adjust-remote-upstream-alist', just like
 when using `magit-branch-and-checkout'."
   (declare (interactive-only magit-call-git))
   (interactive
-   (let* ((current (magit-get-current-branch))
-          (local   (magit-list-local-branch-names))
-          (remote  (seq-filter (##and (string-match "[^/]+/" %)
-                                      (not (member (substring % (match-end 0))
-                                                   (cons "HEAD" local))))
-                               (magit-list-remote-branch-names)))
-          (choices (nconc (delete current local) remote))
-          (atpoint (magit-branch-at-point))
-          (choice  (magit-completing-read
-                    "Checkout branch" choices
-                    nil nil nil 'magit-revision-history
-                    (or (car (member atpoint choices))
-                        (and atpoint
-                             (car (member (and (string-match "[^/]+/" atpoint)
-                                               (substring atpoint (match-end 0)))
-                                          choices)))))))
-     (cond ((member choice remote)
-            (list (and (string-match "[^/]+/" choice)
-                       (substring choice (match-end 0)))
-                  choice))
-           ((member choice local)
-            (list choice))
-           ((list choice (magit-read-starting-point "Create" choice))))))
+    (let* ((current (magit-get-current-branch))
+           (local   (magit-list-local-branch-names))
+           (remote  (seq-filter (##and (string-match "[^/]+/" %)
+                                       (not (member (substring % (match-end 0))
+                                                    (cons "HEAD" local))))
+                                (magit-list-remote-branch-names)))
+           (choices (nconc (delete current local) remote))
+           (atpoint (magit-branch-at-point))
+           (choice  (magit-completing-read
+                     "Checkout branch" choices
+                     nil nil nil 'magit-revision-history
+                     (or (car (member atpoint choices))
+                         (and atpoint
+                              (car (member (and (string-match "[^/]+/" atpoint)
+                                                (substring atpoint (match-end 0)))
+                                           choices)))))))
+      (cond ((member choice remote)
+             (list (and (string-match "[^/]+/" choice)
+                        (substring choice (match-end 0)))
+                   choice))
+            ((member choice local)
+             (list choice))
+            ((list choice (magit-read-starting-point "Create" choice))))))
   (cond
-   ((not start-point)
-    (magit--checkout branch (magit-branch-arguments))
-    (magit-refresh))
-   (t
-    (when (magit-anything-modified-p t)
-      (user-error "Cannot checkout when there are uncommitted changes"))
-    (magit-run-git-async "checkout" (magit-branch-arguments)
-                         "-b" branch start-point)
-    (set-process-sentinel
-     magit-this-process
-     (lambda (process event)
-       (when (memq (process-status process) '(exit signal))
-         (magit-branch-maybe-adjust-upstream branch start-point)
-         (when (magit-remote-branch-p start-point)
-           (pcase-let ((`(,remote . ,remote-branch)
-                        (magit-split-branch-name start-point)))
-             (when (and (equal branch remote-branch)
-                        (not (equal remote (magit-get "remote.pushDefault"))))
-               (magit-set remote "branch" branch "pushRemote"))))
-         (magit-process-sentinel process event)))))))
+    ((not start-point)
+     (magit--checkout branch (magit-branch-arguments))
+     (magit-refresh))
+    (t
+     (when (magit-anything-modified-p t)
+       (user-error "Cannot checkout when there are uncommitted changes"))
+     (magit-run-git-async "checkout" (magit-branch-arguments)
+                          "-b" branch start-point)
+     (set-process-sentinel
+      magit-this-process
+      (lambda (process event)
+        (when (memq (process-status process) '(exit signal))
+          (magit-branch-maybe-adjust-upstream branch start-point)
+          (when (magit-remote-branch-p start-point)
+            (pcase-let ((`(,remote . ,remote-branch)
+                         (magit-split-branch-name start-point)))
+              (when (and (equal branch remote-branch)
+                         (not (equal remote (magit-get "remote.pushDefault"))))
+                (magit-set remote "branch" branch "pushRemote"))))
+          (magit-process-sentinel process event)))))))
 
 (defun magit-branch-maybe-adjust-upstream (branch start-point)
   (when-let ((upstream
@@ -423,20 +423,20 @@ when using `magit-branch-and-checkout'."
   (if magit-branch-read-upstream-first
       (let ((choice (magit-read-starting-point prompt nil default-start)))
         (cond
-         ((magit-rev-verify choice)
-          (list (magit-read-string-ns
-                 (if magit-completing-read--silent-default
-                     (format "%s (starting at `%s')" prompt choice)
-                   "Name for new branch")
-                 (let ((def (string-join (cdr (split-string choice "/")) "/")))
-                   (and (member choice (magit-list-remote-branch-names))
-                        (not (member def (magit-list-local-branch-names)))
-                        def)))
-                choice))
-         ((eq magit-branch-read-upstream-first 'fallback)
-          (list choice
-                (magit-read-starting-point prompt choice default-start)))
-         ((user-error "Not a valid starting-point: %s" choice))))
+          ((magit-rev-verify choice)
+           (list (magit-read-string-ns
+                  (if magit-completing-read--silent-default
+                      (format "%s (starting at `%s')" prompt choice)
+                    "Name for new branch")
+                  (let ((def (string-join (cdr (split-string choice "/")) "/")))
+                    (and (member choice (magit-list-remote-branch-names))
+                         (not (member def (magit-list-local-branch-names)))
+                         def)))
+                 choice))
+          ((eq magit-branch-read-upstream-first 'fallback)
+           (list choice
+                 (magit-read-starting-point prompt choice default-start)))
+          ((user-error "Not a valid starting-point: %s" choice))))
     (let ((branch (magit-read-string-ns (concat prompt " named"))))
       (if (magit-branch-p branch)
           (magit-branch-read-args
@@ -544,13 +544,13 @@ When resetting to another branch and a prefix argument is used,
 then also set the target branch as the upstream of the branch
 that is being reset."
   (interactive
-   (let ((branch (magit-read-local-branch "Reset branch"
-                                          (magit-local-branch-at-point))))
-     (list branch
-           (magit-read-branch-or-commit (format "Reset %s to" branch)
-                                        (magit-get-upstream-branch branch)
-                                        branch)
-           current-prefix-arg)))
+    (let ((branch (magit-read-local-branch "Reset branch"
+                                           (magit-local-branch-at-point))))
+      (list branch
+            (magit-read-branch-or-commit (format "Reset %s to" branch)
+                                         (magit-get-upstream-branch branch)
+                                         branch)
+            current-prefix-arg)))
   (let ((magit-inhibit-refresh t))
     (if (equal branch (magit-get-current-branch))
         (if (and (magit-anything-modified-p)
@@ -560,8 +560,7 @@ that is being reset."
           (magit-reset-hard to))
       (magit-call-git "update-ref"
                       "-m" (format "reset: moving to %s" to)
-                      (magit-git-string "rev-parse" "--symbolic-full-name"
-                                        branch)
+                      (magit-ref-fullname branch)
                       to))
     (when (and set-upstream (magit-branch-p to))
       (magit-set-upstream-branch branch to)
@@ -588,24 +587,24 @@ prompt is confusing."
   ;; `magit-branch-rename'; but it turns out everyone wants to squeeze
   ;; a bit of extra functionality into this one, including myself.
   (interactive
-   (let ((branches (magit-region-values 'branch t))
-         (force current-prefix-arg))
-     (if (length> branches 1)
-         (magit-confirm t nil "Delete %d branches" nil branches)
-       (setq branches
-             (list (magit-read-branch-prefer-other
-                    (if force "Force delete branch" "Delete branch")))))
-     (cond-let
-       (force)
-       [[unmerged (seq-remove #'magit-branch-merged-p branches)]]
-       ((magit-confirm 'delete-unmerged-branch
-          "Delete unmerged branch %s"
-          "Delete %d unmerged branches"
-          'noabort unmerged)
-        (setq force branches))
-       ((setq branches (cl-set-difference branches unmerged :test #'equal)))
-       ((user-error "Abort")))
-     (list branches force)))
+    (let ((branches (magit-region-values 'branch t))
+          (force current-prefix-arg))
+      (if (length> branches 1)
+          (magit-confirm t nil "Delete %d branches" nil branches)
+        (setq branches
+              (list (magit-read-branch-prefer-other
+                     (if force "Force delete branch" "Delete branch")))))
+      (cond-let
+        (force)
+        [[unmerged (seq-remove #'magit-branch-merged-p branches)]]
+        ((magit-confirm 'delete-unmerged-branch
+           "Delete unmerged branch %s"
+           "Delete %d unmerged branches"
+           'noabort unmerged)
+         (setq force branches))
+        ((setq branches (cl-set-difference branches unmerged :test #'equal)))
+        ((user-error "Abort")))
+      (list branches force)))
   (let ((refs (mapcar #'magit-ref-fullname branches)))
     ;; If a member of refs is nil, that means that
     ;; the respective branch name is ambiguous.
@@ -614,86 +613,86 @@ prompt is confusing."
        "%s ambiguous; please cleanup using git directly"
        (let ((len (length ambiguous)))
          (cond
-          ((= len 1)
-           (format "%s is" (seq-find #'magit-ref-ambiguous-p branches)))
-          ((= len (length refs))
-           (format "These %s names are" len))
-          ((format "%s of these names are" len))))))
+           ((= len 1)
+            (format "%s is" (seq-find #'magit-ref-ambiguous-p branches)))
+           ((= len (length refs))
+            (format "These %s names are" len))
+           ((format "%s of these names are" len))))))
     (cond
-     ((string-match "^refs/remotes/\\([^/]+\\)" (car refs))
-      (let* ((remote (match-str 1 (car refs)))
-             (offset (1+ (length remote))))
-        (cond
-         ((magit-confirm 'delete-branch-on-remote
-            (list "Deleting local %s.  Also delete on %s"
-                  (magit-ref-fullname (car branches))
-                  remote)
-            (list "Deleting %d local refs.  Also delete on %s"
-                  (length refs)
-                  remote)
-            'noabort refs)
-          ;; The ref may actually point at another rev on the remote,
-          ;; but this is better than nothing.
-          (dolist (ref refs)
-            (message "Delete %s (was %s)" ref
-                     (magit-rev-parse "--short" ref)))
-          ;; Assume the branches actually still exist on the remote.
-          (magit-run-git-async
-           "push"
-           (and (or force magit-branch-delete-never-verify) "--no-verify")
-           remote
-           (mapcar (##concat ":" (substring % offset)) branches))
-          ;; If that is not the case, then this deletes the tracking branches.
-          (set-process-sentinel
-           magit-this-process
-           (apply-partially #'magit-delete-remote-branch-sentinel remote refs)))
-         (t
-          (dolist (ref refs)
-            (message "Delete %s (was %s)" ref
-                     (magit-rev-parse "--short" ref))
-            (magit-call-git "update-ref" "-d" ref))
-          (magit-refresh)))))
-     ((length> branches 1)
-      (setq branches (delete (magit-get-current-branch) branches))
-      (mapc #'magit-branch-maybe-delete-pr-remote branches)
-      (mapc #'magit-branch-unset-pushRemote branches)
-      (magit-run-git "branch" (if force "-D" "-d") branches))
-     (t ; And now for something completely different.
-      (let* ((branch (car branches))
-             (prompt (format "Branch %s is checked out.  " branch))
-             (target (magit-get-indirect-upstream-branch branch t)))
-        (when (equal branch (magit-get-current-branch))
-          (when (or (equal branch target)
-                    (not target))
-            (setq target (magit-main-branch)))
-          (pcase (if (or (equal branch target)
-                         (not target))
-                     (magit-read-char-case prompt nil
-                       (?d "[d]etach HEAD & delete" 'detach)
-                       (?a "[a]bort"                'abort))
-                   (magit-read-char-case prompt nil
-                     (?d "[d]etach HEAD & delete" 'detach)
-                     (?c (format "[c]heckout %s & delete" target) 'target)
-                     (?a "[a]bort" 'abort)))
-            (`detach (unless (or (equal force '(4))
-                                 (member branch force)
-                                 (magit-branch-merged-p branch t))
-                       (magit-confirm 'delete-unmerged-branch
-                         "Delete unmerged branch %s" ""
-                         nil (list branch)))
-                     (magit-call-git "checkout" "--detach"))
-            (`target (unless (or (equal force '(4))
-                                 (member branch force)
-                                 (magit-branch-merged-p branch target))
-                       (magit-confirm 'delete-unmerged-branch
-                         "Delete unmerged branch %s" ""
-                         nil (list branch)))
-                     (magit-call-git "checkout" target))
-            (`abort  (user-error "Abort")))
-          (setq force t))
-        (magit-branch-maybe-delete-pr-remote branch)
-        (magit-branch-unset-pushRemote branch)
-        (magit-run-git "branch" (if force "-D" "-d") branch))))))
+      ((string-match "^refs/remotes/\\([^/]+\\)" (car refs))
+       (let* ((remote (match-str 1 (car refs)))
+              (offset (1+ (length remote))))
+         (cond
+           ((magit-confirm 'delete-branch-on-remote
+              (list "Deleting local %s.  Also delete on %s"
+                    (magit-ref-fullname (car branches))
+                    remote)
+              (list "Deleting %d local refs.  Also delete on %s"
+                    (length refs)
+                    remote)
+              'noabort refs)
+            ;; The ref may actually point at another rev on the remote,
+            ;; but this is better than nothing.
+            (dolist (ref refs)
+              (message "Delete %s (was %s)" ref
+                       (magit-rev-parse "--short" ref)))
+            ;; Assume the branches actually still exist on the remote.
+            (magit-run-git-async
+             "push"
+             (and (or force magit-branch-delete-never-verify) "--no-verify")
+             remote
+             (mapcar (##concat ":" (substring % offset)) branches))
+            ;; If that is not the case, then this deletes the tracking branches.
+            (set-process-sentinel
+             magit-this-process
+             (apply-partially #'magit-delete-remote-branch-sentinel remote refs)))
+           (t
+            (dolist (ref refs)
+              (message "Delete %s (was %s)" ref
+                       (magit-rev-parse "--short" ref))
+              (magit-call-git "update-ref" "-d" ref))
+            (magit-refresh)))))
+      ((length> branches 1)
+       (setq branches (delete (magit-get-current-branch) branches))
+       (mapc #'magit-branch-maybe-delete-pr-remote branches)
+       (mapc #'magit-branch-unset-pushRemote branches)
+       (magit-run-git "branch" (if force "-D" "-d") branches))
+      (t ; And now for something completely different.
+       (let* ((branch (car branches))
+              (prompt (format "Branch %s is checked out.  " branch))
+              (target (magit-get-indirect-upstream-branch branch t)))
+         (when (equal branch (magit-get-current-branch))
+           (when (or (equal branch target)
+                     (not target))
+             (setq target (magit-main-branch)))
+           (pcase (if (or (equal branch target)
+                          (not target))
+                      (magit-read-char-case prompt nil
+                        (?d "[d]etach HEAD & delete" 'detach)
+                        (?a "[a]bort"                'abort))
+                    (magit-read-char-case prompt nil
+                      (?d "[d]etach HEAD & delete" 'detach)
+                      (?c (format "[c]heckout %s & delete" target) 'target)
+                      (?a "[a]bort" 'abort)))
+             (`detach (unless (or (equal force '(4))
+                                  (member branch force)
+                                  (magit-branch-merged-p branch t))
+                        (magit-confirm 'delete-unmerged-branch
+                          "Delete unmerged branch %s" ""
+                          nil (list branch)))
+                      (magit-call-git "checkout" "--detach"))
+             (`target (unless (or (equal force '(4))
+                                  (member branch force)
+                                  (magit-branch-merged-p branch target))
+                        (magit-confirm 'delete-unmerged-branch
+                          "Delete unmerged branch %s" ""
+                          nil (list branch)))
+                      (magit-call-git "checkout" target))
+             (`abort  (user-error "Abort")))
+           (setq force t))
+         (magit-branch-maybe-delete-pr-remote branch)
+         (magit-branch-unset-pushRemote branch)
+         (magit-run-git "branch" (if force "-D" "-d") branch))))))
 
 (put 'magit-branch-delete 'interactive-only t)
 
@@ -758,11 +757,11 @@ the value of `magit-branch-rename-push-target' (which see) maybe
 set `branch.NEW.pushRemote' and maybe rename the push-target on
 the remote."
   (interactive
-   (let ((branch (magit-read-local-branch "Rename branch")))
-     (list branch
-           (magit-read-string-ns (format "Rename branch '%s' to" branch)
-                                 nil 'magit-revision-history)
-           current-prefix-arg)))
+    (let ((branch (magit-read-local-branch "Rename branch")))
+      (list branch
+            (magit-read-string-ns (format "Rename branch '%s' to" branch)
+                                  nil 'magit-revision-history)
+            current-prefix-arg)))
   (when (string-match "\\`heads/\\(.+\\)" old)
     (setq old (match-str 1 old)))
   (when (equal old new)
@@ -868,11 +867,11 @@ Also rename the respective reflog file."
    ("a m" magit-branch.autoSetupMerge)
    ("a r" magit-branch.autoSetupRebase)]
   (interactive
-   (list (or (and (not current-prefix-arg)
-                  (not (and magit-branch-direct-configure
-                            (eq transient-current-command 'magit-branch)))
-                  (magit-get-current-branch))
-             (magit--read-branch-scope))))
+    (list (or (and (not current-prefix-arg)
+                   (not (and magit-branch-direct-configure
+                             (eq transient-current-command 'magit-branch)))
+                   (magit-get-current-branch))
+              (magit--read-branch-scope))))
   (transient-setup 'magit-branch-configure nil nil :scope branch))
 
 (defun magit--read-branch-scope (&optional obj)
